import { Arrayable } from '@antfu/utils';
import { FilterPattern } from '@rollup/pluginutils';

declare type PresetName = '@nuxtjs/composition-api' | '@vue/composition-api' | '@vueuse/core' | '@vueuse/head' | 'preact' | 'react' | 'vue-demi' | 'vue-i18n' | 'vue-router' | 'vue';

declare type ImportNameAlias = [string, string];
declare type ImportInfo = {
    module: string;
    name: string;
    from?: string;
};
/**
 * module, name, alias
 */
declare type ImportsMap = Record<string, (string | ImportNameAlias)[]>;
/**
 * name, meta
 */
declare type ImportsFlatMap = Record<string, ImportInfo>;
interface Options {
    /**
     * Preset names or custom imports map
     *
     * @default []
     */
    imports?: Arrayable<ImportsMap | PresetName>;
    /**
     * Filepath to generate corresponding .d.ts file.
     * Set `false` to disable.
     *
     * @default './auto-imports.d.ts'
     */
    dts?: string | false;
    /**
     * Allow overriding imports sources from multiple presets.
     *
     * @default false
     */
    presetOverriding?: boolean;
    /**
     * Rules to include transforming target.
     *
     * @default [/\.[jt]sx?$/, /\.vue\??/]
     */
    include?: FilterPattern;
    /**
     * Rules to exclude transforming target.
     *
     * @default [/node_modules/, /\.git/]
     */
    exclude?: FilterPattern;
    /**
     * Generate source map.
     *
     * @default false
     */
    sourceMap?: boolean;
}
interface TransformOptions {
    imports: ImportsFlatMap;
    matchRE: RegExp;
    /**
     * Generate source map.
     *
     * @default false
     */
    sourceMap?: boolean;
}
interface ResolvedOptions extends Omit<Options, 'imports'>, TransformOptions {
    idFilter: (id: string) => boolean;
}

export { ImportInfo, ImportNameAlias, ImportsFlatMap, ImportsMap, Options, PresetName, ResolvedOptions, TransformOptions };
